@@ -7,7 +7,7 @@
 * re-register components.
 *
 */
-#define NS_BUILD_ID 2006121608
+#define NS_BUILD_ID 2007013008
 
 /* GRE_BUILD_ID - GRE build version identifier
  *
@@ -17,7 +17,7 @@
  * GRE_BUILD_ID will just contain <milestone>. 
  *
  */
-#define GRE_BUILD_ID "1.8.1.1_2006121608"
+#define GRE_BUILD_ID "1.8.1.2pre_2007013008"
 
 #endif /* _NSBUILDID_H_ */
 
